package fr.openium.consentium.domain.useCase

import javax.inject.Inject
import kotlin.io.encoding.Base64
import kotlin.io.encoding.ExperimentalEncodingApi

interface GetAuthTokenUseCase {
    suspend operator fun invoke(applicationId: String): String
}

class GetAuthTokenUseCaseImpl @Inject internal constructor(
    private val getConsentiumUniqueInstallationIdUseCase: GetConsentiumUniqueInstallationIdUseCase,
) : GetAuthTokenUseCase {

    @OptIn(ExperimentalEncodingApi::class)
    override suspend operator fun invoke(applicationId: String): String {
        val uniqueInstallationId = getConsentiumUniqueInstallationIdUseCase()
        val clearToken = "$applicationId.$uniqueInstallationId"
        val cipheredToken = Base64.Default.encode(clearToken.toByteArray())
        return "Bearer $cipheredToken"
    }

}
